============
Contributing
============

Bug reports
===========

When `reporting a bug <https://github.com/kitovu-bot/kitovu/issues>`_ please include:

    * Your operating system name and version.
    * Any details about your local setup that might be helpful in troubleshooting.
    * Detailed steps to reproduce the bug.

Code contributions
==================

Since kitovu is currently developed as an university project, we're unable to
accept any outside code contributions. This will change around July 2018.

Documentation
=============

If you want to generate the entire documentation of the project you can create it with::

 sphinx-apidoc --separate --no-toc --force -o docs/reference/complete src
 tox -e docs
